==> leprikon-1.9.2.tar.gz: leprikon-1.9.2/leprikon/__init__.py <==
__version__ = '1.9.2'
default_app_config = 'leprikon.apps.LeprikonConfig'

staticfiles_urls = {
    'leprikon/lib/bootstrap/css/bootstrap-theme.css': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap-theme.css',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap.min.css': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.min.css',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap-theme.css.map': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap-theme.css.map',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap.min.css.map': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.min.css.map',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap-theme.min.css': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap-theme.min.css',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap.css': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.css',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap-theme.min.css.map': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap-theme.min.css.map',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap.css.map': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.css.map',  # NOQA
    'leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.svg': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.svg',  # NOQA
    'leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.ttf': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.ttf',  # NOQA
    'leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.eot': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.eot',  # NOQA
    'leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.woff': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.woff',  # NOQA
    'leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.woff2': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.woff2',  # NOQA
    'leprikon/lib/bootstrap/js/bootstrap.min.js': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/js/bootstrap.min.js',  # NOQA
    'leprikon/lib/bootstrap/js/npm.js': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/js/npm.js',  # NOQA
    'leprikon/lib/bootstrap/js/bootstrap.js': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/js/bootstrap.js',  # NOQA
    'leprikon/lib/bootstrap-datetimepicker.min.css': ('https://cdnjs.cloudflare.com/ajax/libs/bootstrap-datetimepicker/4.17.37/css/bootstrap-datetimepicker.min.css', 'sha384', '/XmhRcB6e51B3NO1S5VVWnNKCDM74NlX0cmxZUwCJPg2P/0ECTkBKnjnzNnF7rX5'),  # NOQA
    'leprikon/lib/bootstrap-datetimepicker.min.js': ('https://cdnjs.cloudflare.com/ajax/libs/bootstrap-datetimepicker/4.17.37/js/bootstrap-datetimepicker.min.js', 'sha384', 'V936AaxnYTkq53cO2z8e42PFtCCdZhbRttfhgX8U1K9weNYVdCMbDetUKTtllFdc'),  # NOQA
    'leprikon/lib/bootstrap-multiselect.css': ('https://cdnjs.cloudflare.com/ajax/libs/bootstrap-multiselect/0.9.13/css/bootstrap-multiselect.css', 'sha384', 'l1tju+TyzPCuWXt+knuFYVhe2ZnnEm0/t9T8BmqNedtIBYj1fmsYrIAap4MU2amm'),  # NOQA
    'leprikon/lib/bootstrap-multiselect.min.js': ('https://cdnjs.cloudflare.com/ajax/libs/bootstrap-multiselect/0.9.13/js/bootstrap-multiselect.min.js', 'sha384', '2q+7Pk3OSOseTKfNi/t8mZzYRIovdg+nfXYeKmmnivkyD+nxosintmGKX7SWcrOG'),  # NOQA
    'leprikon/lib/ekko-lightbox.min.css': ('https://cdnjs.cloudflare.com/ajax/libs/ekko-lightbox/4.0.1/ekko-lightbox.min.css', 'sha384', 'EsoR0pjPTZTUy5b8kJf6aTfA7quYluD5mNQ/Lz4hsxU2kXuuc6PlXVfBJCFdTXqD'),  # NOQA
    'leprikon/lib/ekko-lightbox.min.js': ('https://cdnjs.cloudflare.com/ajax/libs/ekko-lightbox/4.0.1/ekko-lightbox.min.js', 'sha384', '2aVpK/uKiYlyFXHZ36wvxOPZyWeouEKvbSUlqCrkFhyT80n2aSYtT15Tgdn6g41M'),  # NOQA
    'leprikon/lib/jquery.min.js': ('https://cdnjs.cloudflare.com/ajax/libs/jquery/1.12.2/jquery.min.js', 'sha384', 'o6l2EXLcx4A+q7ls2O2OP2Lb2W7iBgOsYvuuRI6G+Efbjbk6J4xbirJpHZZoHbfs'),  # NOQA
    'leprikon/lib/moment-with-locales.min.js': ('https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.12.0/moment-with-locales.min.js', 'sha384', 'V0utPzNT28o7j37Ll4BIKqEVcL1yOE45HoCoaLu/CqF4nFaf2nAyZTHKJW1KdJMH'),  # NOQA
    'leprikon/lib/bootstrap-social.min.css': ('https://cdnjs.cloudflare.com/ajax/libs/bootstrap-social/5.1.1/bootstrap-social.min.css', 'sha384', 'N7gull5mxE2uLDqZ+kcZolhmuopwLtTcThUsVnUS2LVMQljojN9cfJ9A6fUA63zB'),  # NOQA
    'leprikon/lib/font-awesome/css/font-awesome.css': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.css',  # NOQA 
    'leprikon/lib/font-awesome/css/font-awesome.css.map': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.css.map',  # NOQA 
    'leprikon/lib/font-awesome/css/font-awesome.min.css': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css',  # NOQA 
    'leprikon/lib/font-awesome/fonts/FontAwesome.otf': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/fonts/FontAwesome.otf',  # NOQA 
    'leprikon/lib/font-awesome/fonts/fontawesome-webfont.eot': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/fonts/fontawesome-webfont.eot',  # NOQA 
    'leprikon/lib/font-awesome/fonts/fontawesome-webfont.svg': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/fonts/fontawesome-webfont.svg',  # NOQA 
    'leprikon/lib/font-awesome/fonts/fontawesome-webfont.ttf': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/fonts/fontawesome-webfont.ttf',  # NOQA 
    'leprikon/lib/font-awesome/fonts/fontawesome-webfont.woff': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/fonts/fontawesome-webfont.woff',  # NOQA 
    'leprikon/lib/font-awesome/fonts/fontawesome-webfont.woff2': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/fonts/fontawesome-webfont.woff2',  # NOQA 
}

==> leprikon-1.25.0.tar.gz: leprikon-1.25.0/leprikon/__init__.py <==
__version__ = '1.25.0'
default_app_config = 'leprikon.apps.LeprikonConfig'

staticfiles_urls = {
    'leprikon/lib/bootstrap/css/bootstrap-theme.css': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap-theme.css',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap.min.css': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.min.css',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap-theme.css.map': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap-theme.css.map',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap.min.css.map': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.min.css.map',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap-theme.min.css': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap-theme.min.css',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap.css': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.css',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap-theme.min.css.map': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap-theme.min.css.map',  # NOQA
    'leprikon/lib/bootstrap/css/bootstrap.css.map': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/css/bootstrap.css.map',  # NOQA
    'leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.svg': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.svg',  # NOQA
    'leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.ttf': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.ttf',  # NOQA
    'leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.eot': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.eot',  # NOQA
    'leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.woff': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.woff',  # NOQA
    'leprikon/lib/bootstrap/fonts/glyphicons-halflings-regular.woff2': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/fonts/glyphicons-halflings-regular.woff2',  # NOQA
    'leprikon/lib/bootstrap/js/bootstrap.min.js': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/js/bootstrap.min.js',  # NOQA
    'leprikon/lib/bootstrap/js/npm.js': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/js/npm.js',  # NOQA
    'leprikon/lib/bootstrap/js/bootstrap.js': 'https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/3.3.7/js/bootstrap.js',  # NOQA
    'leprikon/lib/bootstrap-datetimepicker.min.css': ('https://cdnjs.cloudflare.com/ajax/libs/bootstrap-datetimepicker/4.17.37/css/bootstrap-datetimepicker.min.css', 'sha384', '/XmhRcB6e51B3NO1S5VVWnNKCDM74NlX0cmxZUwCJPg2P/0ECTkBKnjnzNnF7rX5'),  # NOQA
    'leprikon/lib/bootstrap-datetimepicker.min.js': ('https://cdnjs.cloudflare.com/ajax/libs/bootstrap-datetimepicker/4.17.37/js/bootstrap-datetimepicker.min.js', 'sha384', 'V936AaxnYTkq53cO2z8e42PFtCCdZhbRttfhgX8U1K9weNYVdCMbDetUKTtllFdc'),  # NOQA
    'leprikon/lib/bootstrap-multiselect.css': ('https://cdnjs.cloudflare.com/ajax/libs/bootstrap-multiselect/0.9.13/css/bootstrap-multiselect.css', 'sha384', 'l1tju+TyzPCuWXt+knuFYVhe2ZnnEm0/t9T8BmqNedtIBYj1fmsYrIAap4MU2amm'),  # NOQA
    'leprikon/lib/bootstrap-multiselect.min.js': ('https://cdnjs.cloudflare.com/ajax/libs/bootstrap-multiselect/0.9.13/js/bootstrap-multiselect.min.js', 'sha384', '2q+7Pk3OSOseTKfNi/t8mZzYRIovdg+nfXYeKmmnivkyD+nxosintmGKX7SWcrOG'),  # NOQA
    'leprikon/lib/ekko-lightbox.min.css': ('https://cdnjs.cloudflare.com/ajax/libs/ekko-lightbox/4.0.1/ekko-lightbox.min.css', 'sha384', 'EsoR0pjPTZTUy5b8kJf6aTfA7quYluD5mNQ/Lz4hsxU2kXuuc6PlXVfBJCFdTXqD'),  # NOQA
    'leprikon/lib/ekko-lightbox.min.js': ('https://cdnjs.cloudflare.com/ajax/libs/ekko-lightbox/4.0.1/ekko-lightbox.min.js', 'sha384', '2aVpK/uKiYlyFXHZ36wvxOPZyWeouEKvbSUlqCrkFhyT80n2aSYtT15Tgdn6g41M'),  # NOQA
    'leprikon/lib/jquery.min.js': ('https://cdnjs.cloudflare.com/ajax/libs/jquery/1.12.4/jquery.min.js', 'sha256', 'ZosEbRLbNQzLpnKIkEdrPv7lOy9C27hHQ+Xp8a4MxAQ='),  # NOQA
    'leprikon/lib/moment-with-locales.min.js': ('https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.12.0/moment-with-locales.min.js', 'sha384', 'V0utPzNT28o7j37Ll4BIKqEVcL1yOE45HoCoaLu/CqF4nFaf2nAyZTHKJW1KdJMH'),  # NOQA
    'leprikon/lib/bootstrap-social.min.css': ('https://cdnjs.cloudflare.com/ajax/libs/bootstrap-social/5.1.1/bootstrap-social.min.css', 'sha384', 'N7gull5mxE2uLDqZ+kcZolhmuopwLtTcThUsVnUS2LVMQljojN9cfJ9A6fUA63zB'),  # NOQA
    'leprikon/lib/font-awesome/css/font-awesome.css': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.css',  # NOQA 
    'leprikon/lib/font-awesome/css/font-awesome.css.map': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.css.map',  # NOQA 
    'leprikon/lib/font-awesome/css/font-awesome.min.css': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css',  # NOQA 
    'leprikon/lib/font-awesome/fonts/FontAwesome.otf': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/fonts/FontAwesome.otf',  # NOQA 
    'leprikon/lib/font-awesome/fonts/fontawesome-webfont.eot': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/fonts/fontawesome-webfont.eot',  # NOQA 
    'leprikon/lib/font-awesome/fonts/fontawesome-webfont.svg': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/fonts/fontawesome-webfont.svg',  # NOQA 
    'leprikon/lib/font-awesome/fonts/fontawesome-webfont.ttf': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/fonts/fontawesome-webfont.ttf',  # NOQA 
    'leprikon/lib/font-awesome/fonts/fontawesome-webfont.woff': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/fonts/fontawesome-webfont.woff',  # NOQA 
    'leprikon/lib/font-awesome/fonts/fontawesome-webfont.woff2': 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/fonts/fontawesome-webfont.woff2',  # NOQA 
}
